==> gwyddion_3.7.orig.tar.xz: gwyddion-3.7/gwyddion/gwyddion.h <==
/*
 *  $Id: gwyddion.h 27908 2025-05-05 14:26:24Z yeti-dn $
 *  Copyright (C) 2003-2019 David Necas (Yeti), Petr Klapetek.
 *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor,
 *  Boston, MA 02110-1301, USA.
 */

#ifndef __GWYDDION_GWYDDION_H__
#define __GWYDDION_GWYDDION_H__

#include <gtk/gtkwidget.h>
#include <libgwyddion/gwycontainer.h>
#include <libgwyddion/enum.h>

G_BEGIN_DECLS

#define GWY_TOOLBOX_WM_ROLE "gwyddion-toolbox"

GtkWidget* gwy_app_toolbox_window_create    (void);
GtkWidget* gwy_app_show_data_browser        (void);
void       gwy_app_about                    (void);
void       gwy_app_splash_start             (gboolean visible);
void       gwy_app_splash_finish            (void);
void       gwy_app_splash_set_message       (const gchar *message);
void       gwy_app_splash_set_message_prefix(const gchar *prefix);
gboolean   gwy_app_gl_disabled              (void);
gchar*     gwy_version_date_info            (void);

G_END_DECLS

#endif /* __GWYDDION_GWYDDION_H__ */

/* vim: set cin et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */

==> gwyddion-3.8.tar.xz: gwyddion-3.8/gwyddion/gwyddion.h <==
/*
 *  $Id: gwyddion.h 29478 2026-02-14 13:56:53Z yeti-dn $
 *  Copyright (C) 2003-2019 David Necas (Yeti), Petr Klapetek.
 *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor,
 *  Boston, MA 02110-1301, USA.
 */

#ifndef __GWYDDION_GWYDDION_H__
#define __GWYDDION_GWYDDION_H__

#include <gtk/gtkwidget.h>
#include <libgwyddion/dict.h>
#include <libgwyddion/enum.h>

G_BEGIN_DECLS

#define GWY_TOOLBOX_WM_ROLE "gwyddion-toolbox"

GtkWidget* gwy_app_toolbox_window_create    (void);
GtkWidget* gwy_app_show_data_browser        (void);
void       gwy_app_about                    (void);
void       gwy_app_splash_start             (gboolean visible);
void       gwy_app_splash_finish            (void);
void       gwy_app_splash_set_message       (const gchar *message);
void       gwy_app_splash_set_message_prefix(const gchar *prefix);
gboolean   gwy_app_gl_disabled              (void);
gchar*     gwy_version_date_info            (void);

G_END_DECLS

#endif /* __GWYDDION_GWYDDION_H__ */

/* vim: set cin et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
